@@ -1,6 +1,5 @@
-package # hide from PAUSE
-    Starch::Plugin::CookieArgs::Manager;
-
+package Starch::Plugin::CookieArgs::Manager;
+$Starch::Plugin::CookieArgs::Manager::VERSION = '0.07';
 use Types::Standard -types;
 use Types::Common::String -types;
 use Types::Common::Numeric -types;
